package com.lantone.qc.kernel.catalogue.hospital.beilun.operationdiscussion;

import com.alibaba.fastjson.JSONArray;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.SimilarityServiceClient;
import com.lantone.qc.kernel.structure.ai.ModelAI;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.AnesthesiaRecordDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.util.DateUtil;
import com.lantone.qc.pub.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * @ClassName: OPE03099
 * @Description: 术前诊断与麻醉记录不一致
 * @Author songxl
 * @Date 2021/3/19
 * @Version 1.0
 */
@Component
@Slf4j
public class OPE03099 extends QCCatalogue {
    @Autowired
    SimilarityServiceClient similarityServiceClient;
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 获取手术记录的术后诊断和麻醉记录的术前诊断进行相似度对比
         */
        status.set("0");
        //1.获取患者的手术相关文档,手麻记录
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        if(operationDocs==null||operationDocs.isEmpty())//无手术相关记录
        {
            return;
        }
        List<AnesthesiaRecordDoc> anesthesiaDocs  = inputInfo.getAnesthesiaRecordDocs();
        if(anesthesiaDocs==null|| anesthesiaDocs.isEmpty())//无手麻相关记录
        {
            return;
        }
        //2.遍历获取手术记录
       try{
           for(OperationDoc operationDoc:operationDocs)
           {
               if(operationDoc.getOperationRecordDoc()!=null)
               {
                   //2.1获取手术记录术前诊断、手术时间
                   String diagBeforeOperation = operationDoc.getOperationRecordDoc().getStructureMap().get("术前诊断");
                   Date operationStartTime = DateUtil.parseDateTime(operationDoc.getOperationRecordDoc()
                           .getStructureMap().get("手术开始时间"),"yyyy年MM月dd日HH时mm分");
                   if(operationStartTime==null || StringUtil.isBlank(diagBeforeOperation)) {continue;}
                   anesthesiaDocs.forEach(anesthesiaRecordDoc -> {
                       //2.2遍历手麻记录，找到该手术时间的手麻记录
                       if(anesthesiaRecordDoc.getAnesStartTime()!=null)
                       {
                           if(DateUtils.isSameInstant(operationStartTime,anesthesiaRecordDoc.getAnesStartTime()))
                           {
                               String anesDiagBeforeOperation = anesthesiaRecordDoc.getDiagBeforeOperation();
                               //相似度对比
                               /* 文本相似度模型 */
                               ModelAI modelAI = new ModelAI();
                               JSONArray similarContent = new JSONArray();
                               modelAI.putContent(similarContent,diagBeforeOperation,anesDiagBeforeOperation);
                               double likeRate = modelAI.loadSimilarAI(similarContent, similarityServiceClient);
                               if (likeRate < 0.9) {
                                   status.set("-1");
                                   return;
                               }
                           }
                       }
                   });
               }
           }
       }
       catch (Exception e)
       {
           log.error(e.getMessage(),e);
       }

    }
}
