package com.lantone.qc.kernel.catalogue.hospital.shaoyf.behospitalized;

import com.lantone.qc.dbanaly.lt.entity.Clinic;
import com.lantone.qc.dbanaly.lt.facade.ClinicFacade;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Clinical;
import com.lantone.qc.pub.model.entity.Modification;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @ClassName : BEH0020
 * @Description :  现病史症状缺少缓解情况
 * crf模型中只标注趋势，需要用词库去配出哪些是缓解情况。
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class BEH0020 extends QCCatalogue {
    @Autowired
    private ClinicFacade clinicFacade;

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getBeHospitalizedDoc() == null || inputInfo.getBeHospitalizedDoc().getPresentLabel() == null) {
            return;
        }
        List<Clinical> clinicals = inputInfo.getBeHospitalizedDoc().getPresentLabel().getClinicals();
        if (clinicals.size() > 0) {
            Clinical clinical = clinicals.get(0);
            String clinicalName = clinical.getName();
            if (StringUtil.isNotBlank(clinicalName)) {
                Clinic clinic = clinicFacade.clinicCache(clinicalName);
                if (clinic != null && clinic.getHasRelieve() == 1) {
                    Modification modification = clinical.getModification();
                    if (modification == null || !modification.getName().contains("缓")) {
                        status.set("-1");
                        info.set(clinicalName);
                    }

                    if (clinicals.size() > 1) {
                        String secondeName = clinicals.get(1).getName();
                        String presentText = inputInfo.getBeHospitalizedDoc().getPresentLabel().getText();
                        String subTxt = presentText.substring(presentText.indexOf(clinicalName), presentText.indexOf(secondeName));
                        if (subTxt.indexOf("好转") > -1) {
                            status.set("0");
                        }
                    }
                }
            }
        }
    }

}