package com.lantone.qc.trans.ywzxyy;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.ClinicalBloodDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import com.lantone.qc.trans.ywzxyy.util.YwzxyyClinicalBloodXmlAnalysis;
import com.lantone.qc.trans.ywzxyy.util.YwzxyyXmlAnalysis;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;

import java.util.List;
import java.util.Map;

/**
 * @Description: 输血/血制品病程记录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:21
 */
@Slf4j
public class YwzxyyClinicalBloodDocTrans extends ModelDocTrans {

    @Override
    public List<ClinicalBloodDoc> extract(MedrecVo medrecVo) {
        List<ClinicalBloodDoc> retList = Lists.newArrayList();
        List<Map<String, Object>> contentMaps = (List) medrecVo.getContent().get("content");
        contentMaps.forEach(contentMap -> {
            try {
                ClinicalBloodDoc clinicalBloodDoc = getClinicalBloodDoc(contentMap);
                if (clinicalBloodDoc != null) {
                    retList.add(clinicalBloodDoc);
                }
            } catch (Exception e) {
                log.error(e.getMessage(), e);
            }
        });
        return retList;
    }

    private ClinicalBloodDoc getClinicalBloodDoc(Map<String, Object> contentMap) {
        String content = contentMap.get("xmlText").toString();
        Map<String, String> structureMap = null;
        if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
            structureMap = (Map) FastJsonUtils.getJsonToMap(content);
        } else {
            String recTitle = contentMap.get("recTitle").toString();
            String recTypeId = contentMap.get("recTypeId").toString();
            YwzxyyXmlAnalysis ywzxyyXmlAnalysis = new YwzxyyClinicalBloodXmlAnalysis();
            Map<String, String> sourceMap = ywzxyyXmlAnalysis.analysis(content, recTitle, recTypeId);
            if (MapUtils.isNotEmpty(sourceMap)) {
                structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts, "10");
                structureMap.put("记录编号", contentMap.get("recId").toString());
                structureMap.put("病历号", contentMap.get("behospitalCode") == null ? null : contentMap.get("behospitalCode").toString());
            }
        }
        if (MapUtils.isNotEmpty(structureMap)) {
            ClinicalBloodDoc clinicalBloodDoc = ModelDocGenerate.clinicalBloodDocGen(structureMap);
            clinicalBloodDoc.setPageData((Map) structureMap);
            return clinicalBloodDoc;
        } else {
            return null;
        }
    }

    private List<String> keyContrasts = Lists.newArrayList();

}